@@ -105,12 +105,15 @@ def TBPTT(
     # redo reset in training loop
     utils.reset(net=net)
 
-    neurons_dict = {  # confirm this is even useful
+    neurons_dict = {
         utils.is_lapicque: snn.Lapicque,
         utils.is_leaky: snn.Leaky,
         utils.is_synaptic: snn.Synaptic,
         utils.is_alpha: snn.Alpha,
-        utils.is_stein: snn.Stein,
+        utils.is_rleaky: snn.RLeaky,
+        utils.is_rsynaptic: snn.RSynaptic,
+        utils.is_sconv2dlstm: snn.SConv2dLSTM,
+        utils.is_slstm: snn.SLSTM,
     }
 
     # element 1: if true: spk, if false, mem
@@ -125,6 +128,8 @@ def TBPTT(
         "ce_count_loss": [True, False],
         "mse_count_loss": [True, False],
         "ce_latency_loss": [True, False],
+        "mse_temporal_loss": [True, False],
+        "ce_temporal_loss": [True, False],
     }  # note: when using mse_count_loss, the target spike-count should be for a truncated time, not for the full time
 
     reg_dict = {"l1_rate_sparsity": True}
@@ -267,9 +272,6 @@ def TBPTT(
                 mem_rec_trunc = []
 
         if (step == num_steps - 1) and (num_steps % K):
-            # spk_rec += spk_rec_trunc # test
-            # mem_rec += mem_rec_trunc  # test
-
             spk_rec_trunc = torch.stack(spk_rec_trunc, dim=0)
             mem_rec_trunc = torch.stack(mem_rec_trunc, dim=0)
 
